[![Downloads](https://img.shields.io/pypi/dw/django-search-filter-sort.svg)](https://pypi.python.org/pypi/django-search-filter-sort)
[![Version](https://img.shields.io/pypi/v/django-search-filter-sort.svg)](https://pypi.python.org/pypi/django-search-filter-sort)
[![License](https://img.shields.io/pypi/l/django-search-filter-sort.svg)](https://pypi.python.org/pypi/django-search-filter-sort)
[![Python](https://img.shields.io/pypi/pyversions/django-search-filter-sort.svg)](https://pypi.python.org/pypi/django-search-filter-sort)

Django app designed to help with the creation of list views with full functionality for searching, filtering, and sorting.
If you want to report any bugs, you can use the github issue tracker. If you have comments, please email me at khostetl@nd.edu.

# Requirements

- Python 2.7 and 3+
- Django >=? (I am using 1.10.3 and 1.11)
- django-bootstrap4 >= 0.0.3 (Bootstrap 4 is still currently in Beta)
- jQuery >= ? (I am using 1.12.0)
- Font Awesome Icons installed or linked to your project (Bootstrap 4 no longer has glyphicons)

# Installation

Install the latest release using pip:

`pip install django-search-filter-sort`

Development version can installed using `pip install git+https://github.com/Macainian/Django-Search-Filter-Sort.git`, though be
warned that I don't guarantee anything about the development version. Sometimes it is completely broken because I am
in the middle of major code changes and swapping from one machine to another.

# Usage example

Under construction
